##################################################################################
#
#   MarathUp - Orient Textures command
#
##################################################################################

module Marathon

	def Marathon.orient_textures()
		selection = Sketchup.active_model.selection
		for entity in selection
			if entity.instance_of?(Sketchup::Face)
				type = Marathon.classify_face(entity)
				case type
					when :Floor, :Ceiling
						Marathon.orient_floor_or_ceiling_texture(entity, entity.back_material)
					when :Wall
						Marathon.orient_wall_texture(entity, entity.back_material, false, -1)
						Marathon.orient_wall_texture(entity, entity.material, true, 1)
				end
			end
		end
	end
	
	def Marathon.orient_floor_or_ceiling_texture(face, material)
		if material
			z = face.vertices[0].position.z
			p0 = Geom::Point3d.new(0, 0, z)
			xunit = Geom::Vector3d.new(1, 0, 0)
			yunit = Geom::Vector3d.new(0, 1, 0)
			px = p0 + xunit
			py = p0 + yunit
			uv0 = Geom::Point3d.new(0, 0, 0)
			uvx = Geom::Point3d.new(0, -1, 0)
			uvy = Geom::Point3d.new(-1, 0, 0)
			points = [p0, uv0, px, uvx, py, uvy]
			#printf("orient_floor_or_ceiling_texture:\n") ###
			#printf("p0 = %s, px = %s, py = %s\n", p0.inspect, px.inspect, py.inspect) ###
			#printf("uv0 = %s, uvx = %s, uvy = %s\n", uv0.inspect, uvx.inspect, uvy.inspect) ###
			face.position_material(material, points, false)
		end
	end
	
	def Marathon.orient_wall_texture(face, material, front, sign)
		if material
			p0 = face.vertices[0].position
			n = face.normal
			zunit = Geom::Vector3d.new(0, 0, 1)
			xunit = zunit * n
			px = p0 + xunit
			pz = p0 + zunit
			uv0 = Geom::Point3d.new(0, 0, 0)
			uvx = Geom::Point3d.new(sign, 0, 0)
			uvz = Geom::Point3d.new(0, 1, 0)
			points = [p0, uv0, px, uvx, pz, uvz]
			#printf("orient_wall_texture:\n") ###
			#printf("p0 = %s, px = %s, pz = %s\n", p0.inspect, px.inspect, pz.inspect) ###
			#printf("uv0 = %s, uvx = %s, uvz = %s\n", uv0.inspect, uvx.inspect, uvz.inspect) ###
			face.position_material(material, points, front)
		end
	end
	
end # module Marathon

if not $marathon_orient_textures
	menu = marathon_submenu()
	menu.add_separator()
	menu.add_item("Orient Textures") {Marathon.orient_textures()}
	$marathon_orient_textures = true
end
